@@ -7,8 +7,8 @@ pub use chapter::*;
 use crate::{
     bib,
     config::Config,
-    pandoc::{lua, Pandoc, PandocFormat, PandocOption},
-    Error,
+    error::Error,
+    pandoc::{html_template, latex_template, lua, Pandoc, PandocFormat, PandocOption},
 };
 use anyhow::{anyhow, Context, Result};
 use std::path::PathBuf;
@@ -41,49 +41,82 @@ impl Document {
         }
     }
 
+    fn setup_pandoc(&self) -> Result<Pandoc> {
+        let mut pandoc = Pandoc::new();
+
+        for filter in lua::get_filters()?.iter() {
+            pandoc.push_opt(PandocOption::LuaFilter(filter.to_owned()))
+        }
+
+        for bib_file in bib::get_bib_files(self.root.as_ref()).iter() {
+            pandoc.push_opt(PandocOption::Bibliography(bib_file.to_owned()));
+        }
+
+        for author in self.config.authors.iter() {
+            pandoc.push_opt(PandocOption::Author(author.to_owned()));
+        }
+
+        if self.config.style.number_sections {
+            pandoc.push_opt(PandocOption::NumberSections);
+        }
+
+        if let Some(class) = &self.config.style.document_class {
+            pandoc.push_opt(PandocOption::DocumentClass(class.to_owned()));
+        }
+
+        pandoc.push_opt(PandocOption::Csl(bib::get_csl(&self.config.bib.csl)?));
+        pandoc.push_opt(PandocOption::Title(self.config.title.to_owned()));
+        pandoc.push_opt(PandocOption::Date(self.config.date()));
+        pandoc.push_opt(PandocOption::Citeproc);
+        pandoc.push_opt(PandocOption::LinkCitations);
+        pandoc.push_opt(PandocOption::Standalone);
+        pandoc.push_opt(PandocOption::From(PandocFormat::Markdown));
+
+        Ok(pandoc)
+    }
+
+    pub fn latex(&self) -> Result<String> {
+        Ok(String::from_utf8(self.latex_bytes()?)?)
+    }
+
     pub fn latex_bytes(&self) -> Result<Vec<u8>> {
         if let Some(content) = self.content() {
-            let mut pandoc = Pandoc::new();
-
-            for filter in lua::get_filters()?.iter() {
-                pandoc.push_opt(PandocOption::LuaFilter(filter.to_owned()))
-            }
-
-            for bib_file in bib::get_bib_files(self.root.as_ref()).iter() {
-                pandoc.push_opt(PandocOption::Bibliography(bib_file.to_owned()));
-            }
-
-            for author in self.config.authors.iter() {
-                pandoc.push_opt(PandocOption::Author(author.to_owned()));
-            }
-
-            if self.config.style.number_sections {
-                pandoc.push_opt(PandocOption::NumberSections);
-            }
+            let mut pandoc = self.setup_pandoc()?;
 
             if let Some(header) = self.config.latex_header() {
                 pandoc.include_in_header(&header)?;
             }
 
-            pandoc.push_opt(PandocOption::Csl(bib::get_csl(&self.config.bib.csl)?));
-            pandoc.push_opt(PandocOption::Title(self.config.title.to_owned()));
-            pandoc.push_opt(PandocOption::Date(self.config.date()));
-            pandoc.push_opt(PandocOption::Citeproc); // Use citeproc
-            pandoc.push_opt(PandocOption::LinkCitations); // Link to citations (TODO: Make this optional)
-            pandoc.push_opt(PandocOption::Standalone);
-            pandoc.push_opt(PandocOption::From(PandocFormat::Markdown));
-            pandoc.push_opt(PandocOption::To(PandocFormat::Latex));
+            if let Some(title_script) = &self.config.latex.title_script {
+                pandoc.push_opt(PandocOption::TitleScript(title_script.to_owned()))
+            }
 
-            pandoc.run(content.as_bytes())
+            pandoc.push_opt(PandocOption::Template(latex_template()?));
+            pandoc.push_opt(PandocOption::To(PandocFormat::Latex));
+            pandoc.run(content.as_bytes()).context("Pandoc errored.")
         } else {
             Err(anyhow!("The document has no content.")).context("Cannot convert to LaTeX.")
         }
     }
 
-    pub fn build(&self) -> Result<Vec<u8>> {
+    pub fn html_bytes(&self) -> Result<Vec<u8>> {
+        if let Some(content) = self.content() {
+            let mut pandoc = self.setup_pandoc()?;
+            pandoc.push_opt(PandocOption::Katex);
+            pandoc.push_opt(PandocOption::Template(html_template()?));
+            pandoc.push_opt(PandocOption::To(PandocFormat::Html));
+            pandoc.run(content.as_bytes()).context("Pandoc errored.")
+        } else {
+            Err(anyhow!("The document has no content.")).context("Cannot convert to LaTeX.")
+        }
+    }
+
+    pub fn pdf_bytes(&self) -> Result<Vec<u8>> {
         let filename = &self.config.filename();
 
-        let mut status = crate::log::MdocTectonicStatusBackend;
+        let mut status = crate::log::MdocTectonicStatusBackend {
+            tidy_logs: self.config.build.tidy_logs,
+        };
 
         let config = tectonic::config::PersistentConfig::open(false)
             .map_err(Error::Tectonic)
