@@ -1,4 +1,5 @@
 use anyhow::{anyhow, Error};
+use lazy_static::lazy_static;
 use std::sync::atomic::{AtomicUsize, Ordering};
 
 /// The maximum logging level, stored statically in the memory as an atomic usize.
@@ -8,11 +9,11 @@ static MAX_LOG_LEVEL: AtomicUsize = AtomicUsize::new(0);
 ///
 /// The loggin levels use the following nomenclature:
 ///
-/// - 0: Error
-/// - 1: Success
-/// - 2: Warning
-/// - 3: Info and success
-/// - >4: Debug
+/// - `0`: Error
+/// - `1`: Success
+/// - `2`: Warning
+/// - `3`: Info and success
+/// - `>4`: Debug
 #[inline]
 pub fn set_max_level(level: usize) {
     MAX_LOG_LEVEL.store(level, Ordering::SeqCst);
@@ -23,32 +24,41 @@ pub fn max_level() -> usize {
     MAX_LOG_LEVEL.load(Ordering::Relaxed)
 }
 
-#[macro_export]
-macro_rules! error {
-    ($($arg:tt)*) => ({
-        let text = format!($($arg)*);
-        let mut lines = text.lines();
-        if let Some(line) = lines.next() {
-            eprintln!("\x1B[31mE\x1B[0m {}", line);
-            for line in lines {
-                eprintln!("  {}", line);
-            }
+lazy_static! {
+    pub static ref ICONS: (
+        &'static str,
+        &'static str,
+        &'static str,
+        &'static str,
+        &'static str
+    ) = if std::env::var("NO_COLOR").is_ok() {
+        ("E", "W", "✓", "·", "D")
+    } else {
+        (
+            "\x1B[31mE\x1B[0m",
+            "\x1B[33mW\x1B[0m",
+            "\x1B[32m✓\x1B[0m",
+            "·",
+            "D",
+        )
+    };
+}
+
+pub fn log(icon: &str, text: String) {
+    let mut lines = text.lines();
+    if let Some(line) = lines.next() {
+        eprintln!("{} {}", icon, line);
+        for line in lines {
+            eprintln!("  {}", line);
         }
-    })
+    }
 }
 
 #[macro_export]
-macro_rules! success {
+macro_rules! error {
     ($($arg:tt)*) => ({
         if $crate::log::max_level() >= 1 {
-            let text = format!($($arg)*);
-            let mut lines = text.lines();
-            if let Some(line) = lines.next() {
-                println!("\x1B[32m✓\x1B[0m {}", line);
-                for line in lines {
-                    println!("  {}", line);
-                }
-            }
+            $crate::log::log($crate::log::ICONS.0, format!($($arg)*));
         }
     })
 }
@@ -57,14 +67,16 @@ macro_rules! success {
 macro_rules! warn {
     ($($arg:tt)*) => ({
         if $crate::log::max_level() >= 2 {
-            let text = format!($($arg)*);
-            let mut lines = text.lines();
-            if let Some(line) = lines.next() {
-                eprintln!("\x1B[33mW\x1B[0m {}", line);
-                for line in lines {
-                    eprintln!("  {}", line);
-                }
-            }
+            $crate::log::log($crate::log::ICONS.1, format!($($arg)*));
+        }
+    })
+}
+
+#[macro_export]
+macro_rules! success {
+    ($($arg:tt)*) => ({
+        if $crate::log::max_level() >= 2 {
+            $crate::log::log($crate::log::ICONS.2, format!($($arg)*));
         }
     })
 }
@@ -73,14 +85,7 @@ macro_rules! warn {
 macro_rules! info {
     ($($arg:tt)*) => ({
         if $crate::log::max_level() >= 3 {
-            let text = format!($($arg)*);
-            let mut lines = text.lines();
-            if let Some(line) = lines.next() {
-                println!("  \x1B[90m{}\x1B[0m", line);
-                for line in lines {
-                    println!("  \x1B[90m{}\x1B[0m", line);
-                }
-            }
+            $crate::log::log($crate::log::ICONS.3, format!($($arg)*));
         }
     })
 }
@@ -89,14 +94,7 @@ macro_rules! info {
 macro_rules! debug {
     ($($arg:tt)*) => ({
         if $crate::log::max_level() >= 4 {
-            let text = format!($($arg)*);
-            let mut lines = text.lines();
-            if let Some(line) = lines.next() {
-                println!("D {}", line);
-                for line in lines {
-                    println!("  {}", line);
-                }
-            }
+            $crate::log::log($crate::log::ICONS.4, format!($($arg)*));
         }
     })
 }
@@ -119,7 +117,9 @@ pub fn format_chain(chain: anyhow::Chain) -> String {
     out
 }
 
-pub struct MdocTectonicStatusBackend;
+pub(crate) struct MdocTectonicStatusBackend {
+    pub tidy_logs: bool,
+}
 
 impl tectonic::status::StatusBackend for MdocTectonicStatusBackend {
     fn report(
@@ -130,20 +130,31 @@ impl tectonic::status::StatusBackend for MdocTectonicStatusBackend {
     ) {
         match kind {
             tectonic::status::MessageKind::Error => {
-                let msg = args.to_string();
+                let mut msg = args.to_string();
 
-                error!("{}{}",
-                    msg
+                if self.tidy_logs {
+                    msg = msg
                         .trim_end_matches("See the LaTeX manual or LaTeX Companion for explanation.\nType  H <return>  for immediate help")
                         .trim_start_matches('!')
-                        .trim(),
-                    crate::log::format_chain(err.unwrap_or(&anyhow!("")).chain())
+                        .to_owned();
+                }
+
+                error!(
+                    "{}{}",
+                    msg.trim(),
+                    format_chain(err.unwrap_or(&anyhow!("")).chain())
                 );
             }
             tectonic::status::MessageKind::Warning => {
                 let msg = args.to_string();
-                // Remove all underfull/overfull hbox messages. TODO: Make this optional
-                if !(msg.contains(r"Underfull \hbox") || msg.contains(r"Overfull \hbox")) {
+                // Remove all underfull/overfull vbox/hbox messages.
+                if !self.tidy_logs || !(
+                    msg.contains(r"Underfull \hbox")
+                    || msg.contains(r"Overfull \hbox")
+                    || msg.contains(r"Underfull \vbox")
+                    || msg.contains(r"Overfull \vbox")
+                    || msg.contains(r"warnings were issued by the TeX engine; use --print and/or --keep-logs for details.")
+                ) {
                     warn!("{}", args);
                 }
             }
