@@ -1,4 +1,7 @@
-use anyhow::{Context, Result};
+use crate::{
+    error::{Error, Result},
+    CONFIG_FILE,
+};
 use std::fs::{self, File};
 use std::io::{Read, Write};
 use std::path::{Path, PathBuf};
@@ -8,10 +11,7 @@ use std::process::Command;
 pub(crate) fn read_file<P: AsRef<Path>>(path: P) -> Result<String> {
     let mut buf = String::new();
 
-    File::open(&path)
-        .with_context(|| format!("Unable to open {:?}.", path.as_ref()))?
-        .read_to_string(&mut buf)
-        .with_context(|| format!("Could not read file {:?}.", path.as_ref()))?;
+    File::open(&path)?.read_to_string(&mut buf)?;
 
     Ok(buf)
 }
@@ -20,17 +20,14 @@ pub(crate) fn read_file<P: AsRef<Path>>(path: P) -> Result<String> {
 pub fn write_file(path: &Path, bytes: &[u8]) -> Result<()> {
     // Ensure parent directory (if present)
     if let Some(p) = path.parent() {
-        fs::create_dir_all(p)
-            .with_context(|| format!("Could not create parent directory for {:?}", path))?;
+        fs::create_dir_all(p)?;
     }
 
     // Create file
-    let mut f = File::create(path)
-        .with_context(|| format!("Could not create file from path {:?}", path))?;
+    let mut f = File::create(path)?;
 
     // Write bytes
-    f.write_all(bytes)
-        .with_context(|| format!("Error when writing bytes to {:?}", path))?;
+    f.write_all(bytes)?;
 
     Ok(())
 }
@@ -38,7 +35,7 @@ pub fn write_file(path: &Path, bytes: &[u8]) -> Result<()> {
 /// Finds the root of a MDoc document by looking for a `mdoc.toml` file.
 pub fn find_root() -> Result<PathBuf> {
     let mut path: PathBuf = std::env::current_dir().unwrap();
-    let look_for = Path::new("mdoc.toml");
+    let look_for = Path::new(CONFIG_FILE);
     loop {
         path.push(look_for);
         if path.is_file() {
@@ -46,7 +43,10 @@ pub fn find_root() -> Result<PathBuf> {
             return Ok(path);
         }
         if !(path.pop() && path.pop()) {
-            anyhow::bail!("Unable to find an \"mdoc.toml\" file.")
+            return Err(Error::Io(std::io::Error::new(
+                std::io::ErrorKind::NotFound,
+                "Unable to find an \"mdoc.toml\" file.",
+            )));
         }
     }
 }
@@ -66,6 +66,7 @@ pub fn get_author_name() -> Option<String> {
     }
 }
 
+/// Finds the MDoc data directory
 pub fn data_dir() -> PathBuf {
     dirs::data_dir()
         .expect("Unable to get the data directory.")
